<?php

namespace Drupal\sqrl\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\SettingsCommand;
use Drupal\Core\Url;
use Drupal\user\Entity\User;

/**
 * Provides the SQRL ajax controller.
 */
class Ajax extends Base {

  /**
   * @param null $op
   *
   * @return \Drupal\Core\Access\AccessResult
   */
  public function access($op = NULL): AccessResult {
    if (!$this->client->getNut()->isValid()) {
      return AccessResult::forbidden();
    }
    return AccessResult::allowedIf($op !== NULL && in_array($op, ['markup', 'poll']));
  }

  /**
   * @param $op
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   */
  public function request($op): AjaxResponse {
    $response = new AjaxResponse();
    switch ($op) {
      case 'markup':
        // TODO: Return the SQRL markup and implement display in javascript.
        break;

      case 'poll':
        if (($uid = $this->state->getAuth($this->client->getNut()->getPublicNut())) && ($account = User::load($uid))) {

          $op = $this->client->getNut()->getClientOperation();
          $destination = 'user.page';

          switch ($op) {
            case 'login':
            case 'register':
              // Log user in.
              // If the operation was to register a new user, then the new user account
              // got created by the authentication and hence we also just need to login
              // the user when performing that operation.
              user_login_finalize($account);
              // TODO: destroy other sessions if necessary.
              break;

            case 'link':
              // User linked their account to their SQRL identity.
              break;

          }

          $response->addCommand(new SettingsCommand([
            'sqrl' => [
              'authenticated' => TRUE,
              'destination' => Url::fromRoute($destination)->toString(),
            ],
          ], TRUE));
        }
        break;

    }
    return $response;
  }

}
