<?php

namespace Drupal\sqrl\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\sqrl\Log;
use Drupal\sqrl\Sqrl;
use Drupal\user\Entity\User;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the SQRL link controller.
 */
class Link implements ContainerInjectionInterface {

  /**
   * @var \Drupal\sqrl\Sqrl
   */
  protected $sqrl;

  /**
   * @var \Drupal\sqrl\Log
   */
  protected $log;

  /**
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * Link constructor.
   *
   * @param \Drupal\sqrl\Sqrl $sqrl
   * @param \Drupal\sqrl\Log $log
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   */
  public function __construct(Sqrl $sqrl, Log $log, AccountProxyInterface $current_user) {
    $this->sqrl = $sqrl;
    $this->log = $log;
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('sqrl.handler'),
      $container->get('sqrl.log'),
      $container->get('current_user')
    );
  }

  /**
   * @param \Drupal\user\Entity\User $user
   *
   * @return \Drupal\Core\Access\AccessResult
   */
  public function access(User $user): AccessResult {
    if ($this->currentUser->isAuthenticated() && $this->currentUser->id() === $user->id()) {
      // TODO: Check if the user already has an identity and if multiple identities per account arre allowed.
      return AccessResult::allowed();
    }
    return AccessResult::forbidden();
  }

  /**
   * @param \Drupal\user\Entity\User $user
   *
   * @return array
   */
  public function request(User $user): array {
    return [
      'sqrl' => $this->sqrl->buildMarkup('link'),
    ];
  }

}
