<?php

namespace Drupal\sqrl\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\sqrl\Assets;
use Drupal\sqrl\Log;
use Drupal\sqrl\Sqrl;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the SQRL link controller.
 */
class View implements ContainerInjectionInterface {

  /**
   * @var \Drupal\sqrl\Assets
   */
  protected $assets;

  /**
   * @var \Drupal\sqrl\Sqrl
   */
  protected $sqrl;

  /**
   * @var \Drupal\sqrl\Log
   */
  protected $log;

  /**
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;


  /**
   * Link constructor.
   *
   * @param \Drupal\sqrl\Assets $assets
   * @param \Drupal\sqrl\Sqrl $sqrl
   * @param \Drupal\sqrl\Log $log
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   */
  public function __construct(Assets $assets, Sqrl $sqrl, Log $log, AccountProxyInterface $current_user) {
    $this->assets = $assets;
    $this->sqrl = $sqrl;
    $this->log = $log;
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('sqrl.assets'),
      $container->get('sqrl.handler'),
      $container->get('sqrl.log'),
      $container->get('current_user')
    );
  }

  /**
   * @param string $op
   *
   * @return \Drupal\Core\Access\AccessResult
   */
  public function access($op = NULL) {
    // TODO: check context like anonymous user etc.
    return AccessResult::allowedIf($op !== NULL && in_array($op, ['register', 'login', 'link']));
  }

  /**
   * @param $op
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   */
  public function getTitle($op) {
    return $this->assets->getOperationTitle($op);
  }

  /**
   * @param string $op
   *
   * @return array
   */
  public function request($op): array {
    return [
      'sqrl' => $this->sqrl->buildMarkup($op),
    ];
  }

}
