<?php

namespace Drupal\sqrl\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Defines the sqrl identity entity class.
 *
 * @ContentEntityType(
 *   id = "sqrl_identity",
 *   label = @Translation("SQRL identity"),
 *   handlers = {},
 *   base_table = "sqrl_identity",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "id",
 *     "uuid" = "uuid"
 *   },
 * )
 */
class Identity extends ContentEntityBase implements IdentityInterface {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public function isEnabled(): bool {
    return (bool) $this->get('status')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setStatus($status): IdentityInterface {
    $this->set('status', $status);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime(): int {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setCreatedTime($timestamp): IdentityInterface {
    $this->set('created', $timestamp);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getUid(): int {
    return $this->get('uid')->entity->id();
  }

  /**
   * {@inheritdoc}
   */
  public function getSuk(): string {
    return $this->get('suk')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function getVuk(): string {
    return $this->get('vuk')->value;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Status'))
      ->setDescription(t('A boolean indicating whether the sqrl identity is enabled.'))
      ->setDefaultValue(TRUE)
      ->setSetting('on_label', 'Enabled');

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created on'))
      ->setDescription(t('The time that the sqrl identity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the sqrl identity was last edited.'));

    $fields['uid'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('User'))
      ->setDescription(t('The user ID of this identity.'))
      ->setReadOnly(TRUE)
      ->setSetting('target_type', 'user')
      ->setSetting('handler', 'default');

    $fields['idk'] = BaseFieldDefinition::create('string')
      ->setLabel(t('IDK'))
      ->setDescription(t('The IDK of the identity.'))
      ->setSettings([
        'max_length' => 64,
        'text_processing' => 0,
      ]);
    $fields['suk'] = BaseFieldDefinition::create('string')
      ->setLabel(t('SUK'))
      ->setDescription(t('The SUK of the identity.'))
      ->setSettings([
        'max_length' => 64,
        'text_processing' => 0,
      ]);
    $fields['vuk'] = BaseFieldDefinition::create('string')
      ->setLabel(t('VUK'))
      ->setDescription(t('The VUK of the identity.'))
      ->setSettings([
        'max_length' => 64,
        'text_processing' => 0,
      ]);

    return $fields;
  }

}
