<?php

namespace Drupal\sqrl\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;

/**
 * Provides an interface defining a sqrl entity type.
 */
interface IdentityInterface extends ContentEntityInterface, EntityChangedInterface {

  /**
   * Gets the sqrl creation timestamp.
   *
   * @return int
   *   Creation timestamp of the sqrl.
   */
  public function getCreatedTime(): int;

  /**
   * Sets the sqrl creation timestamp.
   *
   * @param int $timestamp
   *   The sqrl creation timestamp.
   *
   * @return \Drupal\sqrl\Entity\IdentityInterface
   *   The called sqrl entity.
   */
  public function setCreatedTime($timestamp): IdentityInterface;

  /**
   * Returns the sqrl status.
   *
   * @return bool
   *   TRUE if the sqrl is enabled, FALSE otherwise.
   */
  public function isEnabled(): bool;

  /**
   * Sets the sqrl status.
   *
   * @param bool $status
   *   TRUE to enable this sqrl, FALSE to disable.
   *
   * @return \Drupal\sqrl\Entity\IdentityInterface
   *   The called sqrl entity.
   */
  public function setStatus($status): IdentityInterface;

  /**
   * @return int
   */
  public function getUid(): int;

  /**
   * @return string
   */
  public function getSuk(): string;

  /**
   * @return string
   */
  public function getVuk(): string;

}
