<?php

namespace Drupal\sqrl\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure SQRL settings for this site.
 */
class Settings extends ConfigFormBase {

  const MODE_OPTIONAL = 'optional';
  const MODE_EXCLUSIVE = 'exclusive';

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'sqrl_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['sqrl.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('sqrl.settings');
    $form['mode'] = array(
      '#type' => 'radios',
      '#title' => $this->t('Mode'),
      '#description' => $this->t('In exclusive mode, user accounts can only be used with SQRL and username/password authentication no longer works.'),
      '#options' => array(
        self::MODE_OPTIONAL => $this->t('Optional'),
        self::MODE_EXCLUSIVE => $this->t('Exclusive'),
      ),
      '#default_value' => $config->get('mode'),
    );
    $form['session_allow_multiple'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Allow multiple sessions per user account'),
      '#default_value' => $config->get('session_allow_multiple'),
    );
    $form['account_allow_multiple_per_id'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Allow multiple user accounts for each SQRL ID'),
      '#default_value' => $config->get('account_allow_multiple_per_id'),
    );
    $form['id_allow_multiple_per_account'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Allow multiple SQRL IDs per user account'),
      '#default_value' => $config->get('id_allow_multiple_per_account'),
    );
    $form['account_name_pattern'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Pattern for user names when creating them by SQRL'),
      '#description' => $this->t('Use the token [rand] for the random bytes, if missing they get appended.'),
      '#default_value' => $config->get('account_name_pattern'),
    );
    $form['account_name_random_length'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Number of the random bytes'),
      '#size' => 6,
      '#default_value' => $config->get('account_name_random_length'),
    );
    $form['qr_size'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Size of the QR code'),
      '#size' => 6,
      '#default_value' => $config->get('qr_size'),
    );
    $form['poll_interval_initial'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Initial delay before polling starts, in seconds'),
      '#size' => 6,
      '#default_value' => $config->get('poll_interval_initial'),
    );
    $form['poll_interval'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Delay between polling requests, in seconds'),
      '#size' => 6,
      '#default_value' => $config->get('poll_interval'),
    );
    $form['debug'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('In debug mode, JavaScript outputs to the browser console and the server writes to the Drupal logs.'),
      '#default_value' => $config->get('debug'),
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('sqrl.settings')
      ->set('mode', $form_state->getValue('mode'))
      ->set('session_allow_multiple', $form_state->getValue('session_allow_multiple'))
      ->set('account_allow_multiple_per_id', $form_state->getValue('account_allow_multiple_per_id'))
      ->set('id_allow_multiple_per_account', $form_state->getValue('id_allow_multiple_per_account'))
      ->set('account_name_pattern', $form_state->getValue('account_name_pattern'))
      ->set('account_name_random_length', $form_state->getValue('account_name_random_length'))
      ->set('qr_size', $form_state->getValue('qr_size'))
      ->set('poll_interval_initial', $form_state->getValue('poll_interval_initial'))
      ->set('poll_interval', $form_state->getValue('poll_interval'))
      ->set('debug', $form_state->getValue('debug'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
