<?php

namespace Drupal\sqrl;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\Core\Session\AccountProxy;
use Drupal\sqrl\Form\Settings;

/**
 * FormAlter service.
 */
class FormAlter {

  /**
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * @var \Drupal\Core\Session\AccountProxy
   */
  protected $currentUser;

  /**
   * @var \Drupal\sqrl\Sqrl
   */
  protected $sqrl;

  /**
   * @var \Drupal\sqrl\Log
   */
  protected $log;

  /**
   * Constructs a FormAlter object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Session\AccountProxy $current_user
   *   The current user.
   * @param \Drupal\sqrl\Sqrl $sqrl
   *   The SQRL handler.
   * @param \Drupal\sqrl\Log $log
   */
  public function __construct(ConfigFactoryInterface $config_factory, AccountProxy $current_user, Sqrl $sqrl, Log $log) {
    $this->config = $config_factory->get('sqrl.settings');
    $this->currentUser = $current_user;
    $this->sqrl = $sqrl;
    $this->log = $log;
  }

  /**
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   */
  public function loginForm(array &$form, FormStateInterface $form_state) {
    $this->addMarkup($form, 'login');
  }

  /**
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   */
  public function registerForm(array &$form, FormStateInterface $form_state) {
    if ($this->currentUser->isAnonymous()) {
      $this->addMarkup($form, 'register');
    }
  }

  /**
   * @param array $form
   * @param string $op
   */
  private function addMarkup(array &$form, $op) {
    $form['sqrl'] = $this->sqrl->buildMarkup($op);
    $this->alterForm($form);
  }

  /**
   * @param array $form
   */
  private function alterForm(array &$form) {
    if ($this->config->get('mode') === Settings::MODE_EXCLUSIVE) {
      // TODO: Make sure that SQRL alter hooks get executed last, because now
      //   the timezone gets added by system module later and is then visible.
      foreach (Element::children($form) as $field) {
        if ($field !== 'sqrl') {
          $form[$field]['#access'] = FALSE;
        }
      }
    }
  }

}
