<?php

namespace Drupal\sqrl;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Component\Plugin\PluginBase;
use Drupal\Component\Utility\Random;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\sqrl\Entity\Identity;
use Drupal\user\Entity\User;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for sqrl_action plugins.
 */
abstract class SqrlActionPluginBase extends PluginBase implements SqrlActionInterface {

  use StringTranslationTrait;

  /**
   * @var \Drupal\sqrl\Sqrl
   */
  protected $sqrl;

  /**
   * @var \Drupal\sqrl\Client
   */
  protected $client;

  /**
   * @var \Drupal\sqrl\State
   */
  protected $state;

  /**
   * @var \Drupal\sqrl\Log
   */
  protected $log;

  /**
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  /**
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * @var \Drupal\Component\Utility\Random
   */
  protected $random;

  /**
   * @var \Drupal\user\Entity\User
   */
  protected $user;

  /**
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * @var \Drupal\sqrl\SqrlActionPluginManager
   */
  protected $actionPluginManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, Sqrl $sqrl, Client $client, State $state, Log $log, EntityTypeManager $entity_type_manager, ConfigFactory $config_factory, TimeInterface $time, SqrlActionPluginManager $sqrl_action_plugin_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->sqrl = $sqrl;
    $this->client = $client;
    $this->state = $state;
    $this->log = $log;
    $this->entityTypeManager = $entity_type_manager;
    $this->configFactory = $config_factory;
    $this->time = $time;
    $this->actionPluginManager = $sqrl_action_plugin_manager;

    $this->random = new Random();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('sqrl.handler'),
      $container->get('sqrl.client'),
      $container->get('sqrl.state'),
      $container->get('sqrl.log'),
      $container->get('entity_type.manager'),
      $container->get('config.factory'),
      $container->get('datetime.time'),
      $container->get('plugin.manager.sqrl_action')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function label(): string {
    return (string) $this->pluginDefinition['label'];
  }

  /**
   * @param $type
   *
   * @return \Drupal\sqrl\Entity\IdentityInterface|NULL
   */
  private function getIdentity($type) {
    try {
      $id = $this->entityTypeManager->getStorage('sqrl_identity')->getQuery()
        ->condition('uid', $this->user->id())
        ->condition($type, $this->client->getClientVar($type))
        ->execute();
    } catch (InvalidPluginDefinitionException $e) {
    } catch (PluginNotFoundException $e) {
    }
    /** @var \Drupal\sqrl\Entity\IdentityInterface $identity */
    if (isset($id) && $id && $identity = Identity::load(reset($id))) {
      return $identity;
    }
    return NULL;
  }

  /**
   * @return \Drupal\sqrl\Entity\IdentityInterface|NULL
   */
  protected function getIdentityByIdk() {
    return $this->getIdentity('idk');
  }

  /**
   * @return \Drupal\sqrl\Entity\IdentityInterface|NULL
   */
  protected function getIdentityByPidk() {
    return $this->getIdentity('pidk');
  }

  /**
   * {@inheritdoc}
   */
  public function setUser(User $user = NULL): SqrlActionInterface {
    if ($user === NULL) {
      $user = User::load($this->sqrl->getNut()->getClientUid());
    }
    $this->user = $user;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function rememberSuccess(): SqrlActionInterface {
    if ($this->user) {
      $this->state->setAuth($this->client->getNut()->getPublicNut(), $this->user->id());
    }
    return $this;
  }

}
